@@ -3,10 +3,6 @@ set -e
 # Automatically added by dh_installinit
 if [ -x "/etc/init.d/benno-smtp" ]; then
 	update-rc.d benno-smtp defaults >/dev/null
-	if [ -x "`which invoke-rc.d 2>/dev/null`" ]; then
-		invoke-rc.d benno-smtp start || exit $?
-	else
-		/etc/init.d/benno-smtp start || exit $?
-	fi
+	invoke-rc.d benno-smtp start || exit $?
 fi
 # End automatically added section
